===============
User Guide
===============

The User Guide covers concepts within SMRF. This starts with the configuration file
where a user can specify parameters for almost any part of SMRF. The :doc:`CoreConfig <core_config>`
has detailed information on all of the SMRF configuration options. 

.. toctree::
    :maxdepth: 2
    
    configuration
    core_config
    input_data
    dist_methods
    wind_models